==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/adsapp/ronportalform.php <==
<?php
/**
 * UTF8
 * stanislav.elbl, 31.07.2015
 */

namespace Ron\RonPortal;

require_once('ron/form.php');
require_once('adsapp/ronportaldbrecord.php');

use Ron\DB\Database;
use Ron\DBRecordField;
use Ron\FormField;
use Ron\InputForm;
use Ron\MessageManager;
use Ron\StringUtils;
use RonPortal\Controls\OsobaFormField;


/**
 * Pole pro vlozeni RC aktualniho uzivatele
 * Class UserRCField
 * @package Ron\RonPortal
 */
class UserRCField extends FormField
{
    function __construct($fieldname)
    {
        parent::__construct(FORM_FIELD_TYPE_CONSTANT);

        $this->sqlFieldName = $fieldname;   // jmeno pole v databazi
        $this->maxLength = 15;

        $this->defaultValue = User::getRC();
    }
}


/**
 * Pole pro vlozeni Loginu aktualniho uzivatele
 * Class UserLoginField
 * @package Ron\RonPortal
 * @deprecated
 */
class UserLoginField extends \RonPortal\Controls\UserLoginFormField
{
    function __construct($fieldname, $edit)
    {
        parent::__construct($edit, $fieldname);
    }
}


///**
// * Pole pro vlozeni Typu rozdeleni {zvoleneho, nebo podle prav)
// * Class TypRozdeleniField
// * @package Ron\RonPortal
// */
//class TypRozdeleniField extends FormField
//{
//    function __construct($fieldname, $typRozdeleni, $edit)
//    {
//        parent::__construct(FORM_FIELD_TYPE_CONSTANT);
//
//        //$this->fieldName = $fieldname;  // jmeno pole v databazi
//        $this->sqlFieldName = $fieldname;
//        $this->defaultValue = $typRozdeleni;
//        $this->editable = $edit;
//    }
//
//
////    function createDBRecordField($database, $tableName, $insert)
////    {
////        $field = new DBRecordField($this->sqlFieldName, '', !$this->editable, $this->maxLength);
////        $field->setValue($this->typRozdeleni);
////
////        return $field;
////    }
//
//    /**
//     * Nastavi typ rozdeleni, ktery je pouzivany v zadanem typu prava
//     * @param string $typPrava
//     */
//    function setTypRozdeleniPodlePrav($typPrava) {
//        $prava = Prava::vratPrava($typPrava);
//        $this->defaultValue = $prava->typRozdeleni;
//    }
//
//}

/**
 * Class OsobaField
 * @package Ron\RonPortal
 * @deprecated
 */
class OsobaField extends OsobaFormField
{
    /**
     * @param string $caption
     * @param string $prava
     * @param int   $datumPlatnostiPP
     * @param bool  $edit
     */
    function __construct($caption, $prava, $datumPlatnostiPP, $edit)
    {
        parent::__construct($prava, $datumPlatnostiPP);
        $this ->setCaption($caption);
        $this ->setReadOnly(!$edit);
    }
}


/**
 * Class RCOsobyField
 * Pole pro vyber osoby (jen RC, ne pracovni pomer)
 * @package Ron\RonPortal
 */
class RCOsobyField extends FormField
{
    var $prava;
    var $datumPlatnostiPP;
    var $vcetneExternich;

    var $filtr;

    /**
     * OsobaField constructor.
     * @param string $caption nadpis
     * @param string $prava kod prava
     * @param int $datumPlatnostiPP datum ke kteremu se bere platnost prac. pomeru
     * @param bool $edit
     */
    function __construct($caption, $prava, $datumPlatnostiPP, $edit)
    {
        parent::__construct();

        require_once('adsapp/ronportalcontrols.php');

        $this->fieldType = 'osoba';
        $this->fieldName = 'osoba';
        $this->caption = $caption;
        $this->prava = $prava;
        $this->required = true;

        $this->datumPlatnostiPP = $datumPlatnostiPP;
        if (!$this->datumPlatnostiPP) $this->datumPlatnostiPP = time();

        $this->setReadOnly(!$edit);

        $this ->vcetneExternich = false;
    }


    /**
     * @param \Ron\DB\Database $database
     * @param mixed $value
     * @param bool $canEdit
     * @param bool $insert
     * @param array $rowData
     */
    function showFieldContent($database, $value, $canEdit, $insert, $rowData)
    {
        if ($canEdit) {
            $combo = new ComboBoxOsoba($this->fieldName); // jmeno promenne
            $combo->filtr = $this->filtr;
            $combo->className = 'form-input ' . MessageManager::getClass($this ->fieldName);
            $combo->htmlParams = $this->otherHtmlParams;
            $combo->loadDataPP($database,
                $this->datumPlatnostiPP, $this->datumPlatnostiPP,
                Prava::vratPrava($this->prava), ' ', $value, $this ->vcetneExternich); // $emptyRow = ' ', $selectedValue, $vcetneExternich
            $combo->render();
        } else {
            //echo '<input type="hidden" name="' . $this->fieldName . '" value="' . RonPortalSession::vybranaOsoba() . '" />';
            //echo RonPortalSession::osobaJmenoPrijmeni() . "\n";
        }
    }
}

/**
 * Class RonPortalForm
 * @package Ron\RonPortal
 * @deprecated
 */
class RonPortalForm extends \RonPortal\Controls\RonPortalForm
{
    /**
     * @deprecated  Prejmenovano na renderCommonFields
     */
    function showCommonFields()
    {
        parent::renderCommonFields();
    }

    function renderCommonFields()
    {
        $this->showCommonFields();
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2302_169.zip: ronportal/adsapp/ronportalform.php <==
<?php
/**
 * UTF8
 * stanislav.elbl, 31.07.2015
 */

namespace Ron\RonPortal;

require_once('ron/form.php');
require_once('adsapp/ronportaldbrecord.php');

use RonPortal\Controls\UserRCFormField;


/**
 * Pole pro vlozeni RC aktualniho uzivatele
 * Class UserRCField
 * @package Ron\RonPortal
 * @deprecated
 */
class UserRCField extends UserRCFormField
{
}


/**
 * Pole pro vlozeni Loginu aktualniho uzivatele
 * Class UserLoginField
 * @package Ron\RonPortal
 * @deprecated
 */
class UserLoginField extends \RonPortal\Controls\UserLoginFormField
{
    function __construct($fieldname, $edit)
    {
        parent::__construct($edit, $fieldname);
    }
}


///**
// * Pole pro vlozeni Typu rozdeleni {zvoleneho, nebo podle prav)
// * Class TypRozdeleniField
// * @package Ron\RonPortal
// */
//class TypRozdeleniField extends FormField
//{
//    function __construct($fieldname, $typRozdeleni, $edit)
//    {
//        parent::__construct(FORM_FIELD_TYPE_CONSTANT);
//
//        //$this->fieldName = $fieldname;  // jmeno pole v databazi
//        $this->sqlFieldName = $fieldname;
//        $this->defaultValue = $typRozdeleni;
//        $this->editable = $edit;
//    }
//
//
////    function createDBRecordField($database, $tableName, $insert)
////    {
////        $field = new DBRecordField($this->sqlFieldName, '', !$this->editable, $this->maxLength);
////        $field->setValue($this->typRozdeleni);
////
////        return $field;
////    }
//
//    /**
//     * Nastavi typ rozdeleni, ktery je pouzivany v zadanem typu prava
//     * @param string $typPrava
//     */
//    function setTypRozdeleniPodlePrav($typPrava) {
//        $prava = Prava::vratPrava($typPrava);
//        $this->defaultValue = $prava->typRozdeleni;
//    }
//
//}

///**
// * Class OsobaField
// * @package Ron\RonPortal
// * @deprecated
// */
//class OsobaField extends OsobaFormField
//{
//    /**
//     * @param string $caption
//     * @param string $prava
//     * @param int   $datumPlatnostiPP
//     * @param bool  $edit
//     */
//    function __construct($caption, $prava, $datumPlatnostiPP, $edit)
//    {
//        parent::__construct($prava, $datumPlatnostiPP);
//        $this ->setCaption($caption);
//        $this ->setReadOnly(!$edit);
//    }
//}


///**
// * Class RCOsobyField
// * Pole pro vyber osoby (jen RC, ne pracovni pomer)
// * @package Ron\RonPortal
// * @deprecated
// */
//class RCOsobyField extends \RonPortal\Controls\RCOsobyFormField
//{
//    /**
//     * OsobaField constructor.
//     * @param string $caption nadpis
//     * @param string $prava kod prava
//     * @param int $datumPlatnostiPP datum ke kteremu se bere platnost prac. pomeru
//     * @param bool $edit
//     */
//    function __construct($caption, $prava, $datumPlatnostiPP, $edit)
//    {
//        parent::__construct($prava, $datumPlatnostiPP);
//        $this ->setCaption($caption);
//        $this ->setReadOnly(!$edit);
//    }
//}

/**
 * Class RonPortalForm
 * @package Ron\RonPortal
 * @deprecated
 */
class RonPortalForm extends \RonPortal\Controls\RonPortalForm
{
    /**
     * @deprecated  Prejmenovano na renderCommonFields
     */
    function showCommonFields()
    {
        parent::renderCommonFields();
    }

    function renderCommonFields()
    {
        $this->showCommonFields();
    }
}
